@@ -35,7 +35,7 @@ GenOO::Data::File::FASTA - Object implementing methods for accessing fasta forma
 # Let the code begin...
 
 package GenOO::Data::File::FASTA;
-$GenOO::Data::File::FASTA::VERSION = '1.4.6';
+$GenOO::Data::File::FASTA::VERSION = '1.4.8';
 
 #######################################################################
 #######################   Load External modules   #####################
@@ -126,7 +126,10 @@ sub next_record {
 		}
 	}
 	$self->_eof(1);
-	return $self->_create_record;
+	if ($self->_has_stored_record_header) {
+		return $self->_create_record;
+	}
+	return undef;
 }
 
 #######################################################################
